summaryrefslogtreecommitdiff
path: root/src/gui/gtk
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2011-01-01 14:39:12 +0100
committerSebastien Helleu <flashcode@flashtux.org>2011-01-01 14:39:12 +0100
commit0721bb1d4c247b3d063a589644f4b88c2585fedd (patch)
tree9697ebf2eef7c30dbd4c8f83270c22eea3be656b /src/gui/gtk
parent7445c12667766d4a8ea43536325a25a44d5acd18 (diff)
downloadweechat-0721bb1d4c247b3d063a589644f4b88c2585fedd.zip
Add new command /color
Diffstat (limited to 'src/gui/gtk')
-rw-r--r--src/gui/gtk/gui-gtk-color.c54
1 files changed, 52 insertions, 2 deletions
diff --git a/src/gui/gtk/gui-gtk-color.c b/src/gui/gtk/gui-gtk-color.c
index 96d20c4eb..68d0aacbe 100644
--- a/src/gui/gtk/gui-gtk-color.c
+++ b/src/gui/gtk/gui-gtk-color.c
@@ -122,11 +122,21 @@ gui_color_assign_by_diff (int *color, const char *color_name, int diff)
}
/*
* gui_color_get_number: get number of available colors
*/
int
-gui_color_get_number ()
+gui_color_get_weechat_colors_number ()
+{
+ return 0;
+}
+
+/*
+ * gui_color_get_last_pair: get last pair number
+ */
+
+int
+gui_color_get_last_pair ()
{
return 0;
}
@@ -259,6 +269,46 @@ gui_color_display_terminal_colors ()
}
/*
+ * gui_color_buffer_display: display content of color buffer
+ */
+
+void
+gui_color_buffer_display ()
+{
+ /* This function does nothing in Gtk GUI */
+}
+
+/*
+ * gui_color_switch_colrs: switch between WeeChat and terminal colors
+ */
+
+void
+gui_color_switch_colors ()
+{
+ /* This function does nothing in Gtk GUI */
+}
+
+/*
+ * gui_color_buffer_assign: assign color buffer to pointer if it is not yet set
+ */
+
+void
+gui_color_buffer_assign ()
+{
+ /* This function does nothing in Gtk GUI */
+}
+
+/*
+ * gui_color_buffer_open: open a buffer to display colors
+ */
+
+void
+gui_color_buffer_open ()
+{
+ /* This function does nothing in Gtk GUI */
+}
+
+/*
* gui_color_palette_build_aliases: build aliases for palette
*/
@@ -122,11 +122,21 @@ gui_color_assign_by_diff (int *color, const char *color_name, int diff)
}
/*
- * gui_color_get_number: get number of available colors
+ * gui_color_get_weechat_colors_number: get number of available colors
*/
int